@@ -14,19 +14,19 @@ specific language governing permissions and limitations under the License.
 
 class LifeCycleHooksMixin:
     @classmethod
-    def setUpTestData(cls):
+    def set_up_test_data(cls):
         pass
 
     @classmethod
-    def setUpClass(cls):
+    def set_up_class(cls):
         pass
 
     @classmethod
-    def tearDownClass(cls):
+    def tear_down_class(cls):
         pass
 
-    def setUp(self):
+    def set_up(self):
         pass
 
-    def tearDown(self):
+    def tear_down(self):
         pass
